EXPORTS
    ldat   @1 DATA
    dlaunchStartSysModule @2
	dlaunchStartTemps @3

// see below for more info/examples
pldata ldat; // ordinal 1 
DWORD (*dlaunchStartSysModule)(char*); // ordinal 2
BOOL (*dlaunchStartTemps)(DWORD timeInS, DWORD port, BOOL broadcast); // ordinal 3

/********************************** example *******************************************/
#ifdef __cplusplus
extern "C" {
#endif
	UINT32 __stdcall XexGetModuleHandle(char* module, PVOID hand);
	UINT32 __stdcall XexGetProcedureAddress(UINT32 hand ,UINT32, PVOID);
#ifdef __cplusplus
}
#endif
#define NT_SUCCESS(Status)              (((NTSTATUS)(Status)) >= 0)

DWORD (*launchStartSysModule)(char*);
VOID (*someFunct1)(VOID);
VOID (*someFunct2)(VOID);

DWORD resolveFunct(PCHAR modname, DWORD ord)
{
	DWORD ptr2=0;
	HANDLE hand;
	if(NT_SUCCESS(XexGetModuleHandle(modname, &hand)))
		XexGetProcedureAddress(hand, ord, &ptr2);
	return ptr2; // function not found if return is 0
}

//.... in your code

	if(launchStartSysModule == 0)
		launchStartSysModule = (DWORD (__cdecl *)(char*))(resolveFunct("launch.xex", 2));
	DWORD ret = launchStartSysModule("GAME:\\somedll.xex");
	dprintf("launch GAME:\\somedll.xex returned %08x\n"); // returns 0x00000000 on success
	if(someFunct1 == 0)
		someFunct1 = (VOID (__cdecl *)(VOID))(resolveFunct("somedll.xex", 2));
	if(someFunct2 == 0)
		someFunct2 = (VOID (__cdecl *)(VOID))(resolveFunct("somedll.xex", 3));
// etc


//This is the variable exported on ordinal 1

typedef struct _ldata{
	DWORD ID;
	DWORD ltype;
	char link[MAX_PATH];
	char dev[MAX_PATH];
	USHORT versionMaj;
	USHORT versionMin;
	USHORT targetKernel;
	USHORT svnVer;
	DWORD options; // for external apps that want to know what dash launch has set/parsed
	DWORD DebugRoutine; // for external apps that want to recursively hook and call the first/last chance exception trap on their own
	DWORD DebugStepPatch; // address to patch single step exception to not be skipped (write 0x60000000/nop to this address to enable it)
} ldata, *pldata;

/********************************** options bitfields *******************************************/

// options are enumerated by bitmasks, note that changing the var in memory doesn't necissarily enforce the option
// ones that are noted as modifiable can be changed externally, ones that are noted as status it is dangerous to change on the fly
// option bitfields
#define OPT_NXEMINI				0x00000001 // if 1 nxemini miniblade exits in dash are hooked (modifiable)
#define OPT_CONTPATCH			0x00000002 // if 1 LIVE containers will be patched on loads (status)
#define OPT_REGION				0x00000004 // if 1 kernel region was bypassed for this load (status)
#define OPT_DVDEXIT				0x00000008 // if 1 ejecting dvd video will return to official dash (modifiable)
#define OPT_XBLAEXIT			0x00000010 // if 1 quitting a xbla will return to official dash (modifiable)
#define OPT_SOCKPATCH			0x00000020 // if 1 all titles have privs modified for insecure sockets (modifiable)
#define OPT_NOSYSEXIT			0x00000040 // if 1 using miniblades to get to system settings will not work (modifiable)
#define OPT_PASS_LAUNCHD		0x00000080 // if 1 launch data will be passed as-is to the next application (modifiable) 
#define OPT_FATAL_NOFREEZE		0x00000100 // if 1 dash launch tries to catch non-fatal exceptions (status)
#define OPT_FATAL_REBOOT		0x00000200 // if 1 dash launch will try to reboot on fatal exceptions (modifiable/status, depends on NOFREEZE at boot time)
#define OPT_PING_PATCH			0x00000400 // if 1 ping limit has been patched in xam (status)
#define OPT_SAFE_REBOOT			0x00000800 // if 1 changes reboot method to hard reboot for jtag that can't soft reboot (modifiable/status, depends on NOFREEZE at boot time and)
#define OPT_EXCEPT_HANDLE		0x00001000 // if 1 dash launch has hooked the kernel exception handler (status)
#define OPT_DEBUG_OUTPUT		0x00002000 // if 1 dash launch will output dbgprint to UART (status, depends on EXCEPT HANDLE being 1)
#define OPT_UPDATE_BLOCK		0x00004000 // if 1 dash launch is blocking updaters by one-time patching xam strings (status)
#define OPT_LIVE_BLOCK			0x00008000 // if 1 xbox is prevented from resolving known live servers (modifiable)
#define OPT_HUD_DISABLE			0x00010000 // if 1 xbox is preventing HUD miniblades from coming up (status)
#define OPT_XHTTP_PATCHED		0x00020000 // if 1 xam is patched to allow XHTTP to work w/o signing in (status)
#define OPT_SIGN_NOTICE_DISABLE	0x00040000 // if 1 dash launch is dispatching single button warnings generated by singin.xex (status)
#define OPT_SELECT_SHUTDOWN		0x00080000 // if 1 holding guide button will autoselect shutdown console item (modifiable)
#define OPT_FORCE_SHUTDOWN		0x00100000 // if 1 holding guide button will shut down console (modifiable)
#define OPT_BCAST_TEMPS			0x00200000 // if 1 then a task is broadcasting temps and the tempdata export is getting updated (status)
#define OPT_HDALIVE				0x00400000 // if 1 then a task is trying to keep usb hdd from spinning down (status)


//To use the export, you'd do something like:
	pldata ldat = (pldata)resolveFunct("launch.xex", 1);

	
/********************************** temp broadcast info *******************************************/
// this export can be called multiple times, but the task is not set up to be stopped once started
// setting broadcast to TRUE causes it to start broadcasting on a net link if available
// setting it to FALSE stops it from broadcasting, but the task will remain active
// this function returns true if the task is set up successfully (at time of call or before)
BOOL (*dlaunchStartTemps)(DWORD timeInS, DWORD port, BOOL broadcast); // ordinal 3

// temps will be broadcast on a UDB datagram port as specified by the ini
// the basic struct of the data is:
typedef struct _tempMessage {
	BYTE commandIdent; // for temp this will be 0x7
	BYTE cpuLower;
	BYTE cpuUpper;
	BYTE gpuLower;
	BYTE gpuUpper;
	BYTE edramLower;
	BYTE edramUpper;
	BYTE moboLower;
	BYTE moboUpper;
	BYTE unk[7]; // the first byte of this may be smc/southbridge temp in celcius...
} temps, *ptemps;

	BYTE recvData[0x10];
	ptemps temp = (ptemps)recvData;
	// << receive the data from UDP here >>
	if(temp.commandIdent == 0x7)
	{
		double cpu = (temp.cpuLower | (temp.cpuUpper << 8)) / 256.0;
		double gpu = (temp.gpuLower | (temp.gpuUpper << 8)) / 256.0;
		double edram = (temp.edramLower | (temp.edramUpper << 8)) / 256.0;
		double mb = (temp.moboLower | (temp.moboUpper << 8)) / 256.0;
		printf("CPU:%3.1fC GPU:%3.1fC EDRAM:%3.1fC MB:%3.1fC\n", cpu, gpu, edram, mb );
	}
	else
	{ // shouldn't ever happen, but just in case...
		printf("wth is command 0x%x supposed to mean anyway?", temp.commandIdent);
	}

